@@ -182,7 +182,7 @@ namespace Twitterizer
             {
                 if (string.IsNullOrEmpty(this.RetweetCountString)) return null;
 
-                int parsedResult = 0;
+                int parsedResult;
 
                 if (
                     this.RetweetCountString.EndsWith("+") &&
@@ -230,17 +230,19 @@ namespace Twitterizer
         /// <returns></returns>
         public string LinkifiedText()
         {
-            if (this.Entities == null || this.Entities.Count == 0)
+            return LinkifiedText(Entities, Text);
+        }
+
+        internal static string LinkifiedText(TwitterEntityCollection entities, string text)
+        {
+            if (entities == null || entities.Count == 0)
             {
-                return this.Text;
+                return text;
             }
 
-            string linkedText = this.Text;
+            string linkedText = text;
 
-            var entitiesSorted = this
-                                  .Entities
-                                  .OrderBy(e => e.StartIndex)
-                                  .Reverse();
+            var entitiesSorted = entities.OrderBy(e => e.StartIndex).Reverse();
 
             foreach (TwitterEntity entity in entitiesSorted)
             {
@@ -311,7 +313,7 @@ namespace Twitterizer
 		/// </summary>
 		/// <param name="tokens">The tokens.</param>
 		/// <param name="text">The status text.</param>
-		/// <param name="file">The file to upload.</param>
+		/// <param name="fileData">The file to upload, as a byte array.</param>
 		/// <param name="options">The options.</param>
 		/// <returns>
 		/// A <see cref="TwitterStatus"/> object of the newly created status.
