@@ -125,7 +125,22 @@ namespace Smuxi.Engine
             var bld = CreateMessageBuilder().AppendEventPrefix().AppendText(msg);
             Session.AddMessageToChat(NetworkChat, bld.ToMessage());
 
-
+            if (!server.ValidateServerCertificate) {
+                var whitelist = Session.CertificateValidator.HostnameWhitelist;
+                lock (whitelist) {
+                    // needed for favicon
+                    if (!whitelist.Contains("campfirenow.com")) {
+                        whitelist.Add("campfirenow.com");
+                    }
+                    // needed for receiving messages
+                    if (!whitelist.Contains("streaming.campfirenow.com")) {
+                        whitelist.Add("streaming.campfirenow.com");
+                    }
+                    if (!whitelist.Contains(Host)) {
+                        whitelist.Add(Host);
+                    }
+                }
+            }
 
             Client = new JsonServiceClient(BaseUri.AbsoluteUri);
             var creds = new NetworkCredential(server.Username, server.Password);
@@ -182,7 +197,6 @@ namespace Smuxi.Engine
             cd.FrontendManager.AddMessageToChat(cd.Chat, builder.ToMessage());
 
             string[] help = {
-                "help",
                 "connect campfire username password",
                 "list",
                 "uploads",
