@@ -27,15 +27,12 @@ namespace Smuxi.Engine
         Bold      = 2,
         Color     = 3,
         Clear     = 15,
-        Italic    = 26,
+        Italic    = 29,
         Underline = 31,
     }
 
     public class IrcMessageBuilder : MessageBuilder
     {
-#if LOG4NET
-        private static readonly log4net.ILog Logger = log4net.LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType);
-#endif
         private static char[] IrcControlChars { get; set; }
 
         static IrcMessageBuilder()
