@@ -111,13 +111,6 @@ namespace Smuxi.Engine
             }
         }
 
-        static TwitterProtocolManager()
-        {
-            //ServicePointManager.CertificatePolicy = new CertificateValidator();
-            ServicePointManager.ServerCertificateValidationCallback =
-                ValidateCertificate;
-        }
-
         public TwitterProtocolManager(Session session) : base(session)
         {
             Trace.Call(session);
@@ -200,6 +193,19 @@ namespace Smuxi.Engine
                 Session.AddMessageToChat(Chat, builder.ToMessage());
             }
 
+            if (!server.ValidateServerCertificate) {
+                var whitelist = Session.CertificateValidator.HostnameWhitelist;
+                lock (whitelist) {
+                    // needed for favicon
+                    if (!whitelist.Contains("www.twitter.com")) {
+                        whitelist.Add("www.twitter.com");
+                    }
+                    if (!whitelist.Contains("api.twitter.com")) {
+                        whitelist.Add("api.twitter.com");
+                    }
+                }
+            }
+
             string msg;
             msg = String.Format(_("Connecting to Twitter..."));
             fm.SetStatus(msg);
@@ -620,7 +626,6 @@ namespace Smuxi.Engine
             cd.FrontendManager.AddMessageToChat(cd.Chat, builder.ToMessage());
 
             string[] help = {
-                "help",
                 "connect twitter username",
                 "pin pin-number",
             };
@@ -1568,33 +1573,6 @@ namespace Smuxi.Engine
             return (T)(object) builder;
         }
 
-        private static bool ValidateCertificate(object sender,
-                                         X509Certificate certificate,
-                                         X509Chain chain,
-                                         SslPolicyErrors sslPolicyErrors)
-        {
-            if (sslPolicyErrors == SslPolicyErrors.None) {
-                return true;
-            }
-
-            // HACK: Mono's 2.6.7 certificate chain validator is buggy
-            if (sslPolicyErrors == SslPolicyErrors.RemoteCertificateChainErrors &&
-                sender is HttpWebRequest) {
-                var request = (HttpWebRequest) sender;
-                if (request.RequestUri.Host == "api.twitter.com") {
-                    return true;
-                }
-            }
-
-#if LOG4NET
-            f_Logger.Error(
-                "ValidateCertificate(): Certificate error: " +
-                sslPolicyErrors
-            );
-#endif
-            return false;
-        }
-
         private string[] GetApiKey()
         {
             var key = Defines.TwitterApiKey.Split('|');
