@@ -7,7 +7,7 @@
  *
  * Smuxi - Smart MUltipleXed Irc
  *
- * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
+ * Copyright (c) 2005-2013 Mirco Bauer <meebey@meebey.net>
  *
  * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
  *
@@ -86,9 +86,11 @@ namespace Smuxi.Engine
             }
             _IsInitialized = true;
             
-            Assembly asm = Assembly.GetAssembly(typeof(Engine));
-            AssemblyName asm_name = asm.GetName(false);
-            AssemblyProductAttribute pr = (AssemblyProductAttribute)asm.GetCustomAttributes(typeof(AssemblyProductAttribute), false)[0];
+            var asm = Assembly.GetEntryAssembly();
+            if (asm == null) {
+                asm = Assembly.GetAssembly(typeof(Engine));
+            }
+            var asm_name = asm.GetName(false);
             _Version = asm_name.Version;
             _VersionNumber = asm_name.Version.ToString();
 
@@ -98,7 +100,7 @@ namespace Smuxi.Engine
             }
             _VersionString = String.Format(
                 "{0} {1}{2} - running on {3} {4}",
-                pr.Product,
+                Path.GetFileNameWithoutExtension(asm_name.Name),
                 _Version,
                 distVersion,
                 Platform.OperatingSystem,
