@@ -40,6 +40,7 @@ namespace Smuxi.Engine
         private static readonly log4net.ILog f_Logger = log4net.LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType);
 #endif
         private static readonly string                _LibraryTextDomain = "smuxi-engine";
+        public static CertificateValidator CertificateValidator { get; private set; }
         private int                                   _Version = 0;
         private IDictionary<string, FrontendManager>  _FrontendManagers;
         private IList<IProtocolManager>               _ProtocolManagers;
@@ -105,7 +106,13 @@ namespace Smuxi.Engine
                 return _Username == "local";
             }
         }
-        
+
+
+        static Session()
+        {
+            CertificateValidator = new CertificateValidator();
+        }
+
         public Session(Config config, ProtocolManagerFactory protocolManagerFactory,
                        string username)
         {
@@ -195,31 +202,44 @@ namespace Smuxi.Engine
                         continue;
                     }
 
-                    bool isError = false;
-                    try {
-                        IProtocolManager protocolManager = Connect(server, fm);
+                    var msg = String.Format(
+                        _("Automatically connecting to {0}..."),
+                        String.Format("{0}/{1} ({2}:{3})", server.Protocol,
+                                      server.Network, server.Hostname, server.Port)
+                    );
+#if LOG4NET
+                    f_Logger.Info(msg);
+#endif
+                    fm.SetStatus(msg);
 
-                        // if the connect command was correct, we should be
-                        // able to get the chat model
-                        if (protocolManager.Chat == null) {
+                    var srv = server;
+                    // run connects in background threads as they block
+                    ThreadPool.QueueUserWorkItem(delegate {
+                        bool isError = false;
+                        try {
+                            IProtocolManager protocolManager = Connect(srv, fm);
+
+                            // if the connect command was correct, we should be
+                            // able to get the chat model
+                            if (protocolManager.Chat == null) {
+                                isError = true;
+                            }
+                        } catch (Exception ex) {
+#if LOG4NET
+                            f_Logger.Error("RegisterFrontendUI(): Exception during "+
+                                           "automatic connect: ", ex);
+#endif
                             isError = true;
                         }
-                    } catch (Exception ex) {
-#if LOG4NET
-                        f_Logger.Error("RegisterFrontendUI(): Exception during "+
-                                       "automatic connect: ", ex);
-#endif
-                        isError = true;
-                    }
-                    if (isError) {
-                        var builder = CreateMessageBuilder();
-                        builder.AppendErrorText(
-                            _("Automatic connect to {0} failed!"),
-                            server.Hostname + ":" + server.Port
-                        );
-                        fm.AddMessageToChat(_SessionChat, builder.ToMessage());
-                        continue;
-                    }
+                        if (isError) {
+                            var builder = CreateMessageBuilder();
+                            builder.AppendErrorText(
+                                _("Automatic connect to {0} failed!"),
+                                srv.Hostname + ":" + srv.Port
+                            );
+                            fm.AddMessageToChat(_SessionChat, builder.ToMessage());
+                        }
+                    });
                 }
             }
         }
@@ -389,6 +409,10 @@ namespace Smuxi.Engine
                         CommandShutdown(cd);
                         handled = true;
                         break;
+                    case "echo":
+                        CommandEcho(cd);
+                        handled = true;
+                        break;
                 }
             } else {
                 // normal text
@@ -416,7 +440,6 @@ namespace Smuxi.Engine
             cd.FrontendManager.AddMessageToChat(cd.Chat, builder.ToMessage());
 
             string[] help = {
-                "help",
                 "connect/server protocol [protocol-parameters]",
                 "connect/server network",
                 "disconnect [server]",
@@ -718,8 +741,19 @@ namespace Smuxi.Engine
 #endif
             lock (_ProtocolManagers) {
                 foreach (var protocolManager in _ProtocolManagers) {
-                    protocolManager.Disconnect(cmd.FrontendManager);
-                    protocolManager.Dispose();
+                    try {
+                        protocolManager.Disconnect(cmd.FrontendManager);
+                        protocolManager.Dispose();
+                    } catch (Exception ex) {
+#if LOG4NET
+                        f_Logger.ErrorFormat(
+                            "CommandShutdown(): {0}.Disconnect/Dispose() " +
+                            "failed, continuing with shutdown...",
+                            protocolManager.ToString()
+                        );
+                        f_Logger.Error("CommandShutdown(): Exception", ex);
+#endif
+                    }
                 }
             }
 
@@ -734,6 +768,25 @@ namespace Smuxi.Engine
             Environment.Exit(0);
         }
 
+        public void CommandEcho(CommandModel cmd)
+        {
+            Trace.Call(cmd);
+
+            if (cmd == null) {
+                throw new ArgumentNullException("cmd");
+            }
+
+            var msg = new MessageBuilder().
+                AppendEventPrefix().
+                    AppendText(cmd.Parameter).
+                    ToMessage();
+            if (cmd.FrontendManager == null) {
+                AddMessageToChat(cmd.Chat, msg, true);
+            } else {
+                cmd.FrontendManager.AddMessageToChat(cmd.Chat, msg);
+            }
+        }
+
         public void CommandNetwork(CommandModel cd)
         {
             Trace.Call(cd);
@@ -1487,6 +1540,13 @@ namespace Smuxi.Engine
                 // TODO: use a timeout here to only refresh once in 1 second
                 _Filters = _FilterListController.GetFilterList().Values;
             }
+            if (e.Key == "Interface/Notebook/EngineBufferLines") {
+                lock (_Chats) {
+                    foreach (var chat in _Chats) {
+                        chat.ApplyConfig(UserConfig);
+                    }
+                }
+            }
        }
 
         public void CheckPresenceStatus()
@@ -1623,10 +1683,11 @@ namespace Smuxi.Engine
             Trace.Call();
 
             try {
-                var url = "http://news.smuxi.org/feed.php";
-                var req = WebRequest.Create(url);
                 var proxySettings = new ProxySettings();
                 proxySettings.ApplyConfig(UserConfig);
+
+                var url = "http://news.smuxi.org/feed.php";
+                var req = WebRequest.Create(url);
                 req.Proxy = proxySettings.GetWebProxy(url);
                 if (req is HttpWebRequest) {
                     var httpReq = (HttpWebRequest) req;
