@@ -43,7 +43,7 @@ namespace Smuxi.Frontend.Gnome
             }
             Version += "\n Frontend: " + Frontend.UIName + " " + version  +
                        "\n Engine: " + Frontend.EngineVersion;
-            Copyright = "Copyright © 2005-2012 Mirco Bauer <meebey@meebey.net>";
+            Copyright = "Copyright © 2005-2013 Mirco Bauer <meebey@meebey.net>";
             Authors = new string[] {
                 "Mirco Bauer <meebey@meebey.net>",
                 "David Paleino <dapal@debian.org>",
@@ -59,8 +59,9 @@ namespace Smuxi.Frontend.Gnome
                 "Rodney Dawes <dobey@novell.com>",
                 "Lapo Calamandrei <calamandrei@gmail.com>",
                 "Ahmed Abdellah <a3dman1@gmail.com>",
-                "Matthieu James <matthieu.james@gmail.com>",
-                "George Karavasilev <motorslav@gmail.com>"
+                "George Karavasilev <motorslav@gmail.com>",
+                "Joern Konopka <cldx3000@googlemail.com>",
+                "Nuno F. Pinheiro <nuno@oxygen-icons.org>"
             };
             TranslatorCredits = _("translator-credits");
             Logo = Frontend.LoadIcon(
