@@ -21,6 +21,7 @@
  */
 
 using System;
+using System.Linq;
 using System.Runtime.InteropServices;
 using System.Threading;
 using System.Collections;
@@ -252,10 +253,16 @@ namespace Smuxi.Frontend.Gnome
                 QueueDraw();
             }
 
+            if (ChatViewManager.CurrentChatView == null) {
+                // we are during a sync, so don't process keys yet
+                return;
+            }
+
             int keynumber = (int)e.Event.KeyValue;
             Gdk.Key key = e.Event.Key;
-            if ((e.Event.State & Gdk.ModifierType.ControlMask) != 0) {
-                // ctrl is pressed
+            if ((e.Event.State & Gdk.ModifierType.ControlMask) != 0 ||
+                (Frontend.IsMacOSX && (e.Event.State & Gdk.ModifierType.MetaMask) != 0)) {
+                // ctrl / cmd is pressed
                 e.RetVal = true;
                 switch (key) {
                     case Gdk.Key.x:
@@ -551,10 +558,6 @@ namespace Smuxi.Frontend.Gnome
                         _CommandDetach(cd);
                         handled = true;
                         break;
-                    case "echo":
-                        _CommandEcho(cd);
-                        handled = true;
-                        break;
                     case "window":
                         _CommandWindow(cd);
                         handled = true;
@@ -571,6 +574,10 @@ namespace Smuxi.Frontend.Gnome
                         _CommandSync(cd);
                         handled = true;
                         break;
+                    case "sort":
+                        CommandSort(cd);
+                        handled = true;
+                        break;
                     case "gc":
                         GC.Collect();
                         handled = true;
@@ -595,9 +602,9 @@ namespace Smuxi.Frontend.Gnome
             chatView.AddMessage(builder.ToMessage());
 
             string[] help = {
-            "help",
             "window (number|channelname|queryname|close)",
             "sync",
+            "sort",
             "clear",
             "echo data",
             "exec command",
@@ -623,15 +630,6 @@ namespace Smuxi.Frontend.Gnome
             Frontend.Quit();
         }
 
-        private void _CommandEcho(CommandModel cd)
-        {
-            var msg = new MessageBuilder().
-                AppendEventPrefix().
-                AppendText(cd.Parameter).
-                ToMessage();
-            cd.FrontendManager.AddMessageToChat(cd.Chat, msg);
-        }
-    
         private void _CommandWindow(CommandModel cd)
         {
             if (cd.DataArray.Length >= 2) {
@@ -687,15 +685,16 @@ namespace Smuxi.Frontend.Gnome
             var chatView = ChatViewManager.CurrentChatView;
             ThreadPool.QueueUserWorkItem(delegate {
                 try {
+                    var oldValue = Frontend.UseLowBandwidthMode;
                     // HACK: force a full sync
                     Frontend.UseLowBandwidthMode = false;
                     chatView.Sync();
-                    Frontend.UseLowBandwidthMode = true;
+                    Frontend.UseLowBandwidthMode = oldValue;
 
                     Gtk.Application.Invoke(delegate {
                         Frontend.UseLowBandwidthMode = false;
                         chatView.Populate();
-                        Frontend.UseLowBandwidthMode = true;
+                        Frontend.UseLowBandwidthMode = oldValue;
                         chatView.ScrollToEnd();
                     });
                 } catch (Exception ex) {
@@ -704,48 +703,85 @@ namespace Smuxi.Frontend.Gnome
             });
         }
 
+        void CommandSort(CommandModel cmd)
+        {
+            var chats = new List<ChatView>(ChatViewManager.Chats);
+            // as the sorting does 2 remoting calls, we use a background thread
+            ThreadPool.QueueUserWorkItem(delegate {
+                try {
+                    chats.Sort((x, y) => {
+                        if (x.ProtocolManager != null &&
+                            y.ProtocolManager != null &&
+                            x.ProtocolManager != y.ProtocolManager) {
+                            // REMOTING CALL 1
+                            var xprot = x.ProtocolManager.Protocol;
+                            // REMOTING CALL 2
+                            var yprot = y.ProtocolManager.Protocol;
+                            var prot = xprot.CompareTo(yprot);
+                            if (prot != 0) {
+                                return prot;
+                            }
+
+                            // theirs protocols are equal, so their network decide
+                            // REMOTING CALL 3
+                            var xnet = x.ProtocolManager.NetworkID;
+                            // REMOTING CALL 4
+                            var ynet = y.ProtocolManager.NetworkID;
+                            var net = xnet.CompareTo(ynet);
+                            if (net != 0) {
+                               return net;
+                            }
+                        }
+
+                        // their networks are equal, so their type decide
+                        var type = GetChatSortValue(y).CompareTo(GetChatSortValue(x));
+                        if (type != 0) {
+                            return type;
+                        }
+
+                        // their types are equal, so their name decides
+                        return x.ID.CompareTo(y.ID);
+                    });
+
+                    Gtk.Application.Invoke(delegate {
+                        for (int i = 0; i < chats.Count; i++) {
+                            Frontend.MainWindow.Notebook.ReorderChild(chats[i], i);
+                        }
+                    });
+                } catch (Exception ex) {
+#if LOG4NET
+                    _Logger.Error("CommandSort(): Exception", ex);
+#endif
+                }
+            });
+        }
+
+        int GetChatSortValue(ChatView chat)
+        {
+            int status = 0;
+            if (chat is SessionChatView) {
+                status += 100;
+            }
+            if (chat is ProtocolChatView) {
+                status += 50;
+            }
+            if (chat is GroupChatView) {
+                status += 10;
+            }
+            return status;
+        }
+
         private void _CommandClear(CommandModel cd)
         {
             ChatViewManager.CurrentChatView.Clear();
         }
 
-        void CommandGenerateMessages(CommandModel cd)
+        void CommandGenerateMessages(CommandModel cmd)
         {
-            var count = 0;
-            Int32.TryParse(cd.Parameter, out count);
-
             var chat = ChatViewManager.CurrentChatView;
+            _CommandManager.CommandGenerateMessages(cmd, chat);
+
             var builder = new MessageBuilder();
-            var sender = new ContactModel("msg-tester", "msg-tester", "test", "test");
-            builder.AppendMessage(sender, "time for a messsage generator command so I can test speed and memory usage");
-            var text = builder.CreateText(" *formatted text* ");
-            text.Bold = true;
-            builder.Append(text);
-            builder.AppendUrl("https://www.smuxi.org/");
-
-            var msgs = new List<MessageModel>(count);
-            for (var i = 0; i < count; i++) {
-                var msg = builder.ToMessage();
-                msgs.Add(msg);
-            }
-
-            DateTime start, stop;
-            start = DateTime.UtcNow;
-            foreach (var msg in msgs) {
-                chat.AddMessage(msg);
-            }
-            stop = DateTime.UtcNow;
-
-            builder = new MessageBuilder();
-            builder.AppendText(
-                "ChatView.AddMessage(): count: {0} took: {1:0} ms avg: {2:0.00} ms",
-                count,
-                (stop - start).TotalMilliseconds,
-                (stop - start).TotalMilliseconds / count
-            );
-            chat.AddMessage(builder.ToMessage());
-
-            builder = new MessageBuilder();
             builder.AppendText(
                 "ChatView.AddMessage(): MessageTextTagTable.Size: {0}",
                 chat.OutputMessageTextView.MessageTextTagTable.Size
