@@ -1,7 +1,7 @@
 /*
  * Smuxi - Smart MUltipleXed Irc
  *
- * Copyright (c) 2005-2011 Mirco Bauer <meebey@meebey.net>
+ * Copyright (c) 2005-2013 Mirco Bauer <meebey@meebey.net>
  *
  * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
  *
@@ -458,6 +458,7 @@ namespace Smuxi.Frontend.Gnome
                     }
                     Session = _MainWindow.EngineManager.Session;
                     _UserConfig = _MainWindow.EngineManager.UserConfig;
+                    EngineVersion = _MainWindow.EngineManager.EngineVersion;
 
                     Gtk.Application.Invoke(delegate {
                         Frontend.ConnectEngineToGUI();
@@ -512,7 +513,13 @@ namespace Smuxi.Frontend.Gnome
 
                 DisconnectEngineFromGUI();
             }
-            
+
+#if LOG4NET
+            // HACK: workaround log4net deadlock issue. Not sure if it has any
+            // effect though, see: https://www.smuxi.org/issues/show/876
+            log4net.Core.LoggerManager.Shutdown();
+#endif
+
             Gtk.Application.Quit();
             
             Environment.Exit(0);
@@ -1077,17 +1084,21 @@ namespace Smuxi.Frontend.Gnome
                 }
             }
             var appIconDir = Path.Combine(appDir, "icons");
-            if (Directory.Exists(appIconDir) &&
-                (Frontend.IsMacOSX ||
-                 Frontend.IsWindows ||
-                 unityWithLightIcons)) {
-                var iconTheme = "Faenza-Smuxi";
+            if (Directory.Exists(appIconDir)) {
+                var iconTheme = "Smuxi-Symbolic";
 #if LOG4NET
                 _Logger.InfoFormat("InitGtk(): Setting icon theme to: {0}",
                                     iconTheme);
 #endif
+                var origin = Assembly.GetExecutingAssembly().FullName;
                 settings.SetStringProperty(
-                    "gtk-icon-theme-name", iconTheme, Assembly.GetExecutingAssembly().FullName
+                    "gtk-icon-theme-name", iconTheme, origin
+                );
+                settings.SetLongProperty(
+                    "gtk-menu-images", 0, origin
+                 );
+                settings.SetLongProperty(
+                    "gtk-button-images", 0, origin
                 );
 #if LOG4NET
                 _Logger.InfoFormat("InitGtk(): Prepending {0} to icon search path",
