@@ -1,6 +1,6 @@
 // Smuxi - Smart MUltipleXed Irc
 // 
-// Copyright (c) 2010-2011 Mirco Bauer <meebey@meebey.net>
+// Copyright (c) 2010-2013 Mirco Bauer <meebey@meebey.net>
 // 
 // Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
 // 
@@ -168,8 +168,6 @@ namespace Smuxi.Frontend.Gnome
                 App.Register();
 #endif
                 IsEnabled = true;
-                // hide the main window instead of closing it
-                MainWindow.NotificationAreaIconMode = NotificationAreaIconMode.Closed;
             } else {
                 // non-persistent in menu using the blacklist as per
                 // specification:
@@ -246,6 +244,7 @@ namespace Smuxi.Frontend.Gnome
             }
 
             e.ChatView.OutputMessageTextView.MessageHighlighted -= handler;
+            HighlightEventHandlers.Remove(e.ChatView);
 
             // close possibly active indicator
 #if INDICATE_SHARP
@@ -282,9 +281,9 @@ namespace Smuxi.Frontend.Gnome
     #if LOG4NET
                 Logger.Info("Init(): no DBus provider for messaging menu found, " +
                             "disabling...");
+    #endif
                 return;
             }
-    #endif
 #endif
 
             Server = Server.RefDefault();
@@ -435,9 +434,9 @@ namespace Smuxi.Frontend.Gnome
     #if LOG4NET
                 Logger.Info("Init(): no DBus provider for messaging menu found, " +
                             "disabling...");
+    #endif
                 return;
             }
-    #endif
 #endif
 
             App = new App("smuxi-frontend-gnome.desktop");
