@@ -305,6 +305,14 @@ namespace Smuxi.Frontend.Gnome
             string connect_commands = String.Join("\n", (string[])Frontend.UserConfig["Connection/OnConnectCommands"]);
             ((Gtk.TextView)_Glade["OnConnectCommandsTextView"]).Buffer.Text = connect_commands;
 
+            var autoConvertUTF8CheckButton = (Gtk.CheckButton) _Glade["AutoConvertUTF8CheckButton"];
+            if (Frontend.EngineVersion >= new Version("0.8.12")) {
+                autoConvertUTF8CheckButton.Active =
+                    (bool) Frontend.UserConfig["Connection/AutoConvertUTF8"];
+            } else {
+                autoConvertUTF8CheckButton.Sensitive = false;
+            }
+
             string encoding = (string)Frontend.UserConfig["Connection/Encoding"];
             encoding = encoding.ToUpper();
 
@@ -681,7 +689,12 @@ namespace Smuxi.Frontend.Gnome
                 ((Gtk.Entry)_Glade["ConnectionRealnameEntry"]).Text;
             Frontend.UserConfig["Connection/OnConnectCommands"] = 
                 ((Gtk.TextView)_Glade["OnConnectCommandsTextView"]).Buffer.Text.Split(new char[] {'\n'});
-            
+
+            if (Frontend.EngineVersion >= new Version("0.8.12")) {
+                Frontend.UserConfig["Connection/AutoConvertUTF8"] =
+                    ((Gtk.CheckButton)_Glade["AutoConvertUTF8CheckButton"]).Active;
+            }
+
             Gtk.ComboBox cb = (Gtk.ComboBox)_Glade["EncodingComboBox"];
             Gtk.TreeIter iter;
             cb.GetActiveIter(out iter);
@@ -1036,6 +1049,7 @@ namespace Smuxi.Frontend.Gnome
             ((Gtk.Entry) _Glade["ConnectionUsernameEntry"]).Visible = showAdvanced;
             ((Gtk.Label) _Glade["EncodingLabel"]).Visible = showAdvanced;
             ((Gtk.ComboBox) _Glade["EncodingComboBox"]).Visible = showAdvanced;
+            ((Gtk.CheckButton) _Glade["AutoConvertUTF8CheckButton"]).Visible = showAdvanced;
             ((Gtk.Frame) _Glade["NetworkProxyFrame"]).Visible = showAdvanced;
             ((Gtk.Frame) _Glade["GlobalCommandsFrame"]).Visible = showAdvanced;
         }
