@@ -24,6 +24,7 @@ using System;
 using System.Threading;
 using System.Collections.Generic;
 using System.Globalization;
+using System.Linq;
 using Mono.Unix;
 using Smuxi.Engine;
 using Smuxi.Common;
@@ -51,6 +52,9 @@ namespace Smuxi.Frontend.Gnome
         private Gtk.TreeViewColumn _IdentityNameColumn;
         IDictionary<string, PersonModel> SyncedPersons { get; set; }
         MessageModel                     SyncedTopic  { get; set; }
+        public override IList<PersonModel> Participants { get; protected set; }
+        protected Gtk.CellRendererText IdentityNameCellRenderer { get; set; }
+        Gtk.ScrolledWindow PersonScrolledWindow { get; set; }
 
         public override bool HasSelection {
             get {
@@ -82,20 +86,6 @@ namespace Smuxi.Frontend.Gnome
             }
         }
 
-        public override IList<PersonModel> Participants {
-            get {
-                var participants = new List<PersonModel>();
-                if (_PersonListStore == null) {
-                    return participants;
-                }
-                foreach (object[] row in _PersonListStore) {
-                    var person = (PersonModel) row[0];
-                    participants.Add(person);
-                }
-                return participants;
-            }
-        }
-
         protected Gtk.TreeView PersonTreeView {
             get {
                 return _PersonTreeView;
@@ -134,12 +124,46 @@ namespace Smuxi.Frontend.Gnome
             _GroupChatModel = groupChat;
             
             // person list
+            Participants = new List<PersonModel>();
             _OutputHPaned = new Gtk.HPaned();
-            
+            _OutputHPaned.ButtonPressEvent += (sender, e) => {;
+                // reset person list size on double click
+                if (e.Event.Type == Gdk.EventType.TwoButtonPress &&
+                    e.Event.Button == 1) {
+                    GLib.Timeout.Add(200, delegate {
+                        _OutputHPaned.Position = -1;
+                        return false;
+                    });
+                }
+            };
+
             Gtk.ScrolledWindow sw = new Gtk.ScrolledWindow();
-            //sw.WidthRequest = 150;
+            PersonScrolledWindow = sw;
             sw.HscrollbarPolicy = Gtk.PolicyType.Never;
-            
+            sw.SizeRequested += (o, args) => {
+                // predict and set useful treeview width
+                var persons = SyncedPersons;
+                if (persons == null || persons.Count == 0) {
+                    return;
+                }
+
+                int longestNameWidth = 0;
+                foreach (var person in persons.Values) {
+                    int lineWidth, lineHeigth;
+                    using (var layout = _PersonTreeView.CreatePangoLayout(person.IdentityName)) {
+                        layout.GetPixelSize(out lineWidth, out lineHeigth);
+                    }
+                    if (lineWidth > longestNameWidth) {
+                        longestNameWidth = lineWidth;
+                    }
+                }
+
+                var bestSize = new Gtk.Requisition() {
+                    Width = longestNameWidth
+                };
+                args.Requisition = bestSize;
+            };
+
             Gtk.TreeView tv = new Gtk.TreeView();
             _PersonTreeView = tv;
             //tv.CanFocus = false;
@@ -149,7 +173,7 @@ namespace Smuxi.Frontend.Gnome
             
             Gtk.TreeViewColumn column;
             Gtk.CellRendererText cellr = new Gtk.CellRendererText();
-            cellr.WidthChars = 12;
+            IdentityNameCellRenderer = cellr;
             column = new Gtk.TreeViewColumn(String.Empty, cellr);
             column.SortColumnId = 0;
             column.Spacing = 0;
@@ -301,7 +325,8 @@ namespace Smuxi.Frontend.Gnome
             Trace.Call();
 
             // sync persons
-            if (_PersonTreeView != null) {
+            var persons = SyncedPersons;
+            if (_PersonTreeView != null && persons != null) {
                 // HACK: out of scope
                 string status = String.Format(
                                     _("Retrieving user list for {0}..."),
@@ -313,31 +338,25 @@ namespace Smuxi.Frontend.Gnome
                 ls.Clear();
                 // detach the model (less CPU load)
                 _PersonTreeView.Model = new Gtk.ListStore(typeof(PersonModel));
+                Participants = new List<PersonModel>();
                 string longestName = String.Empty;
-                foreach (PersonModel person in SyncedPersons.Values) {
+                foreach (var person in persons.Values.OrderBy(x => x)) {
                     ls.AppendValues(person);
                     
                     if (person.IdentityName.Length > longestName.Length) {
                         longestName = person.IdentityName;
                     }
+                    Participants.Add(person);
                 }
                 // attach the model again
                 // BUG? TreeView doesn't seem to recognize existing values in the model?!?
                 // see: http://www.smuxi.org/issues/show/132
                 _PersonTreeView.Model = ls;
                 _PersonTreeView.SearchColumn = 0;
-                
-                /*
-                // predict and set useful width
-                Console.WriteLine("longestNickname: " + longestName);
-                Pango.Layout layout = _PersonScrolledWindow.CreatePangoLayout(longestName);
-                //_PersonScrolledWindow.WidthRequest = layout.Width;
-                Console.WriteLine("layout.Width: " + layout.Width);
-                _PersonScrolledWindow.SetSizeRequest(layout.Width, 0);
-                */
-                
-                UpdatePersonCount(); 
-               
+
+                PersonScrolledWindow.CheckResize();
+                UpdatePersonCount();
+
                 // TRANSLATOR: this string will be appended to the one above
                 status += String.Format(" {0}", _("done."));
                 Frontend.MainWindow.Status = status;
@@ -348,6 +367,26 @@ namespace Smuxi.Frontend.Gnome
 
             base.Populate();
         }
+
+        public override void AddMessage(MessageModel msg)
+        {
+            base.AddMessage(msg);
+
+            var nick = msg.GetNick();
+            if (nick == null) {
+                return;
+            }
+
+            // update who spoke last
+            for (int i = 0; i < Participants.Count; ++i) {
+                var speaker = Participants[i];
+                if (speaker.IdentityName == nick) {
+                    Participants.RemoveAt(i);
+                    Participants.Insert(0, speaker);
+                    break;
+                }
+            }
+        }
         
         protected void UpdatePersonCount()
         {
@@ -365,6 +404,7 @@ namespace Smuxi.Frontend.Gnome
             }
             
             _PersonListStore.AppendValues(person);
+            Participants.Add(person);
             UpdatePersonCount();
         }
         
@@ -395,6 +435,13 @@ namespace Smuxi.Frontend.Gnome
             } while (_PersonListStore.IterNext(ref iter));
             _PersonTreeView.CheckResize();
             //_PersonListStore.Reorder();
+
+            for (int i = 0; i < Participants.Count; ++i) {
+                if (Participants[i].ID == oldPerson.ID) {
+                    Participants[i] = newPerson;
+                    break;
+                }
+            }
         }
         
         public void RemovePerson(PersonModel person)
@@ -422,6 +469,14 @@ namespace Smuxi.Frontend.Gnome
                     break;
                 }
             } while (_PersonListStore.IterNext(ref iter));
+
+            for (int i = 0; i < Participants.Count; ++i) {
+                if (Participants[i].ID == person.ID) {
+                    Participants.RemoveAt(i);
+                    break;
+                }
+            }
+
             UpdatePersonCount();
         }
 
@@ -480,11 +535,11 @@ namespace Smuxi.Frontend.Gnome
                 _OutputHPaned.Remove(_OutputVBox);
             }
             if (userlist_pos == "left") {
-                _OutputHPaned.Pack1(_PersonTreeViewFrame, false, false);
+                _OutputHPaned.Pack1(_PersonTreeViewFrame, false, true);
                 _OutputHPaned.Pack2(_OutputVBox, true, true);
             } else if (userlist_pos == "right") {
                 _OutputHPaned.Pack1(_OutputVBox, true, true);
-                _OutputHPaned.Pack2(_PersonTreeViewFrame, false, false);
+                _OutputHPaned.Pack2(_PersonTreeViewFrame, false, true);
             } else if (userlist_pos == "none") {
                 _OutputHPaned.Pack1(_OutputVBox, true, true);
             } else {
