@@ -27,6 +27,7 @@
  */
 
 using System;
+using System.Collections.Generic;
 using Smuxi.Engine;
 using Smuxi.Common;
 
@@ -62,6 +63,15 @@ namespace Smuxi.Frontend.Gnome
             ShowAll();
         }
 
+        public override IList<PersonModel> Participants
+        {
+            get {
+                var ret = new List<PersonModel>();
+                ret.Add(PersonChatModel.Person);
+                return ret;
+            }
+        }
+
         public override void Sync()
         {
             Trace.Call();
