@@ -87,7 +87,16 @@ namespace Smuxi.Frontend.Gnome
             // Twitter
             NetworkWebsiteUrls.Add("Twitter", "http://www.twitter.com/");
 
-            // XMPP
+            // XMPP - with federation
+            NetworkWebsiteUrls.Add("XMPP", "http://xmpp.org/");
+            NetworkWebsiteUrls.Add("jabber.org", "http://planet.jabber.org/");
+            NetworkWebsiteUrls.Add("jabber.de", "http://www.jabber.de/");
+            NetworkWebsiteUrls.Add("jabber.at", "http://planet.jabber.org/");
+            NetworkWebsiteUrls.Add("jabber.ccc.de", "http://web.jabber.ccc.de/");
+            NetworkWebsiteUrls.Add("xmpp-gmx.gmx.net", "http://planet.jabber.org/");
+            NetworkWebsiteUrls.Add("xmpp-webde.gmx.net", "http://planet.jabber.org/");
+            NetworkWebsiteUrls.Add("jabber.gmx.net", "http://planet.jabber.org/");
+            // XMPP - without federation
             NetworkWebsiteUrls.Add("talk.google.com", "http://www.google.com/talk/");
             NetworkWebsiteUrls.Add("chat.facebook.com", "http://www.facebook.com/");
 
@@ -96,6 +105,19 @@ namespace Smuxi.Frontend.Gnome
 
             // Campfire
             NetworkWebsiteUrls.Add("Campfire", "http://campfirenow.com");
+
+            // support downloading favicons via https
+            var whitelist = Session.CertificateValidator.HostnameWhitelist;
+            lock (whitelist) {
+                foreach (var url in NetworkWebsiteUrls.Values) {
+                    var uri = new Uri(url);
+                    var hostname = uri.Host;
+                    if (whitelist.Contains(hostname)) {
+                        continue;
+                    }
+                    whitelist.Add(hostname);
+                }
+            }
         }
 
         public ProtocolChatView(ChatModel chat) : base(chat)
@@ -220,8 +242,6 @@ namespace Smuxi.Frontend.Gnome
                 // download in background so Sync() doesn't get slowed down
                 ThreadPool.QueueUserWorkItem(delegate {
                     try {
-                        // HACK: work around Mono's buggy certificate validation
-                        ServicePointManager.ServerCertificateValidationCallback += ValidateCertificate;
                         DownloadServerIcon(websiteUrl, iconFile);
                         iconFile.Refresh();
                         if (!iconFile.Exists || iconFile.Length == 0) {
@@ -232,8 +252,6 @@ namespace Smuxi.Frontend.Gnome
 #if LOG4NET
                         f_Logger.Error("CheckIcon(): Exception", ex);
 #endif
-                    } finally {
-                        ServicePointManager.ServerCertificateValidationCallback -= ValidateCertificate;
                     }
                 });
             }
@@ -253,8 +271,8 @@ namespace Smuxi.Frontend.Gnome
                     // null so explicitely override this by setting an empty proxy
                     proxy = new WebProxy();
                 }
+                webClient.Proxy = proxy;
             }
-            webClient.Proxy = proxy;
             var content = webClient.DownloadString(websiteUrl);
             var links = new List<Dictionary<string, string>>();
             foreach (Match linkMatch in Regex.Matches(content, @"<link[\s]+([^>]*?)/?>")) {
@@ -300,7 +318,10 @@ namespace Smuxi.Frontend.Gnome
 #endif
 
             var iconRequest = WebRequest.Create(faviconUrl);
-            iconRequest.Proxy = proxy;
+            // ignore proxy settings of remote engines
+            if (Frontend.IsLocalEngine) {
+                iconRequest.Proxy = proxy;
+            }
             if (iconRequest is HttpWebRequest) {
                 var iconHttpRequest = (HttpWebRequest) iconRequest;
                 if (iconFile.Exists) {
