@@ -1,8 +1,6 @@
-// $Id$
-// 
 // Smuxi - Smart MUltipleXed Irc
 // 
-// Copyright (c) 2010 Mirco Bauer <meebey@meebey.net>
+// Copyright (c) 2010-2013 Mirco Bauer <meebey@meebey.net>
 // 
 // Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
 // 
@@ -46,6 +44,28 @@ namespace Smuxi.Frontend.Gnome
             }
         }
 
+        public string Protocol {
+            set {
+                Gtk.ListStore store = (Gtk.ListStore) ProtocolComboBox.Model;
+                int protocolPosition = -1;
+                int j = 0;
+                foreach (object[] row in store) {
+                    string protocolName = (string) row[0];
+                    if (protocolName == value) {
+                        protocolPosition = j;
+                        break;
+                    }
+                    j++;
+                }
+                if (protocolPosition == -1) {
+                    throw new ArgumentOutOfRangeException(
+                        "Unsupported protocol: " + value
+                    );
+                }
+                f_ProtocolComboBox.Active = protocolPosition;
+            }
+        }
+
         public Gtk.ComboBoxEntry NetworkComboBoxEntry {
             get {
                 return f_NetworkComboBoxEntry;
@@ -110,22 +130,8 @@ namespace Smuxi.Frontend.Gnome
 
             // protocol is part of the PKEY, not allowed to change
             f_ProtocolComboBox.Sensitive = false;
-            Gtk.ListStore store = (Gtk.ListStore) ProtocolComboBox.Model;
 
-            int protocolPosition = -1;
-            int j = 0;
-            foreach (object[] row in store) {
-                string protocolName = (string) row[0];
-                if (protocolName == server.Protocol) {
-                    protocolPosition = j;
-                    break;
-                }
-                j++;
-            }
-            if (protocolPosition == -1) {
-                throw new ApplicationException("Unsupported protocol: " + server.Protocol);
-            }
-            f_ProtocolComboBox.Active = protocolPosition;
+            Protocol = server.Protocol;
             ServerID = server.ServerID;
             f_HostnameEntry.Text = server.Hostname;
             f_NetworkComboBoxEntry.Entry.Text = server.Network;
@@ -199,7 +205,12 @@ namespace Smuxi.Frontend.Gnome
             }
             store.SetSortColumnId(0, Gtk.SortType.Ascending);
             f_ProtocolComboBox.Model = store;
-            f_ProtocolComboBox.Active = 0;
+
+            try {
+                // select IRC by default (if available)
+                Protocol = "IRC";
+            } catch (ArgumentOutOfRangeException) {
+            }
         }
 
         public void InitNetworks(IList<string> networks)
@@ -266,6 +277,9 @@ namespace Smuxi.Frontend.Gnome
                 case "IRC":
                     f_PortSpinButton.Value = useEncryption ? 6697 : 6667;
                     break;
+                case "JabbR":
+                    f_PortSpinButton.Value = useEncryption ? 443 : 80;
+                    break;
             }
         }
 
@@ -324,10 +338,14 @@ namespace Smuxi.Frontend.Gnome
                     ShowHostname = false;
                     ShowNetwork = false;
                     ShowPassword = false;
-                    SupportUseEncryption = false;
+                    SupportUseEncryption = true;
+                    // engine always uses https
+                    f_UseEncryptionCheckButton.Active = true;
+                    f_UseEncryptionCheckButton.Sensitive = false;
 
                     f_HostnameEntry.Text = String.Empty;
-                    f_PortSpinButton.Value = 0;
+                    f_PortSpinButton.Value = 443;
+                    f_PortSpinButton.Sensitive = false;
                     f_NetworkComboBoxEntry.Entry.Text = String.Empty;
                     f_PasswordEntry.Text = String.Empty;
                     break;
@@ -335,11 +353,28 @@ namespace Smuxi.Frontend.Gnome
                     ShowHostname = true;
                     ShowNetwork = false;
                     ShowPassword = true;
-                    SupportUseEncryption = false;
+                    SupportUseEncryption = true;
+                    // engine always uses https
+                    f_UseEncryptionCheckButton.Active = true;
+                    f_UseEncryptionCheckButton.Sensitive = false;
 
                     f_HostnameEntry.Text = ".campfirenow.com";
                     f_HostnameEntry.Sensitive = true;
-                    f_PortSpinButton.Value = 0;
+                    f_PortSpinButton.Value = 443;
+                    f_PortSpinButton.Sensitive = false;
+                    f_NetworkComboBoxEntry.Entry.Text = String.Empty;
+                    f_PasswordEntry.Text = String.Empty;
+                    break;
+                case "JabbR":
+                    ShowHostname = true;
+                    ShowNetwork = false;
+                    ShowPassword = true;
+                    SupportUseEncryption = true;
+
+                    f_HostnameEntry.Text = "jabbr.net";
+                    f_HostnameEntry.Sensitive = true;
+                    f_PortSpinButton.Sensitive = true;
+                    f_UseEncryptionCheckButton.Active = true;
                     f_NetworkComboBoxEntry.Entry.Text = String.Empty;
                     f_PasswordEntry.Text = String.Empty;
                     break;
