@@ -1,7 +1,7 @@
 /*
  * Smuxi - Smart MUltipleXed Irc
  *
- * Copyright (c) 2007, 2010-2011 Mirco Bauer <meebey@meebey.net>
+ * Copyright (c) 2007, 2010-2013 Mirco Bauer <meebey@meebey.net>
  *
  * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
  *
@@ -38,7 +38,6 @@ namespace Smuxi.Frontend.Stfl
         private static readonly string    _Name = "smuxi";
         private static readonly string    _UIName = "STFL";
         private static Version            _Version;
-        private static string             _VersionNumber;
         private static string             _VersionString;
         private static Version            _EngineVersion;
         private static MainWindow         _MainWindow;
@@ -47,6 +46,8 @@ namespace Smuxi.Frontend.Stfl
         private static UserConfig         _UserConfig;
         private static FrontendManager    _FrontendManager;
         
+        public static event EventHandler SessionPropertyChanged;
+
         public static string Name {
             get {
                 return _Name;
@@ -92,6 +93,10 @@ namespace Smuxi.Frontend.Stfl
             }
             set {
                 _Session = value;
+
+                if (SessionPropertyChanged != null) {
+                    SessionPropertyChanged(value, EventArgs.Empty);
+                }
             }
         }
         
@@ -132,7 +137,6 @@ namespace Smuxi.Frontend.Stfl
             AssemblyProductAttribute pr = (AssemblyProductAttribute)asm.
                 GetCustomAttributes(typeof(AssemblyProductAttribute), false)[0];
             _Version = asm_name.Version;
-            _VersionNumber = asm_name.Version.ToString();
             _VersionString = pr.Product + " - " + _UIName + " frontend " + _Version;
 
             // this always calls abort() :(((
@@ -163,20 +167,17 @@ namespace Smuxi.Frontend.Stfl
                 // not hitting a key
                 _MainWindow.Run(500);
             }
-#if LOG4NET
-           _Logger.Warn("_MainWindow.Run() returned!");
-#endif
         }
         
         public static void InitLocalEngine()
         {
             Engine.Engine.Init();
             _EngineVersion = Engine.Engine.Version;
-            _Session = new Engine.Session(Engine.Engine.Config,
-                                          Engine.Engine.ProtocolManagerFactory,
-                                          "local");
-            _Session.RegisterFrontendUI(_MainWindow.UI);
-            _UserConfig = _Session.UserConfig;
+            Session = new Engine.Session(Engine.Engine.Config,
+                                         Engine.Engine.ProtocolManagerFactory,
+                                         "local");
+            Session.RegisterFrontendUI(_MainWindow.UI);
+            _UserConfig = Session.UserConfig;
             ConnectEngineToGUI();
         }
         
@@ -203,7 +204,7 @@ namespace Smuxi.Frontend.Stfl
                     Environment.Exit(1);
                 }
 
-                _Session = manager.Session;
+                Session = manager.Session;
                 _UserConfig = manager.UserConfig;
                 _EngineVersion = manager.EngineVersion;
                 ConnectEngineToGUI();
@@ -241,6 +242,17 @@ namespace Smuxi.Frontend.Stfl
             _Session = null;
         }
         
+        public static void ApplyConfig(UserConfig userConfig)
+        {
+            Trace.Call(userConfig);
+
+            if (userConfig == null) {
+                throw new ArgumentNullException("userConfig");
+            }
+
+            _MainWindow.ApplyConfig(userConfig);
+        }
+
         public static void Quit()
         {
             if (_FrontendManager != null) {
